Constellation

Struct Constellation 

pub struct Constellation {
    pub id: Id,
    pub created_at: NumericDate,
    pub inner: Inner,
}
Public details on the constellation of PubHubs servers (stored in the inner field) paired with an derived id. Derefs to Inner.

Comparing constellations

Constellation does not implement PartialEq, because there are two valid ways to compare constellations c1 and c2, namely c1.id == c2.id and c1.inner == c2.inner, and it should be clear in the code which one is being used.

Fields

id: Id

Identifier for this constellation derived from Inner using a hash.

created_at: NumericDate

When this constellation was first created by pubhubs central. When two parties have different constellations, the party with the oldest constellation should update.

inner: Inner

Methods from Deref<Target = Inner>

pub fn url(&self, name: Name) -> &Url

Returns the url of the named server

pub(crate) fn sha256(&self) -> Sha256

Returns a sha2::Sha256 hash of this constellation - used to compute Constellation::id.

pub fn derive_id(&self) -> Id