pub struct Constellation {
pub id: Id,
pub created_at: NumericDate,
pub inner: Inner,
}Expand description
Public details on the constellation of PubHubs servers (stored in the inner field)
paired with an derived id. Derefs to Inner.
Comparing constellations
Constellation does not implement PartialEq, because there are two valid ways to compare
constellations c1 and c2, namely c1.id == c2.id and c1.inner == c2.inner, and it should
be clear in the code which one is being used.
Fields
id: IdIdentifier for this constellation derived from Inner using a hash.
created_at: NumericDateWhen this constellation was first created by pubhubs central. When two parties have different constellations, the party with the oldest constellation should update.
inner: InnerTrait Implementations
Sourceimpl Clone for Constellation
impl Clone for Constellation
Sourcefn clone(&self) -> Constellation
fn clone(&self) -> Constellation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Constellation
impl Debug for Constellation
Sourceimpl Deref for Constellation
impl Deref for Constellation
Sourceimpl<'de> Deserialize<'de> for Constellation
impl<'de> Deserialize<'de> for Constellation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&Constellation> for ConstellationClaim
impl From<&Constellation> for ConstellationClaim
Sourcefn from(c: &Constellation) -> Self
fn from(c: &Constellation) -> Self
Converts to this type from the input type.